Injectables
===========

Here are the supported injectables.


.. autoclass:: hgraph.InjectableTypesEnum
    :members:

.. autoclass:: hgraph.STATE
    :members:
    :undoc-members:


.. autoclass:: hgraph.SCHEDULER
    :members:
    :undoc-members:


.. autoclass:: hgraph.LOGGER
    :members:
    :undoc-members:


.. autoclass:: hgraph.EvaluationClock
    :members:
    :undoc-members:


.. autoclass:: hgraph.EvaluationEngineApi
    :members:
    :undoc-members: